//---------------------------------------------------------------
// Library for Monochrome OLEDs based on SSH1106 drivers
//
// igiCOM   - igor.calmicov@gmail.com
//---------------------------------------------------------------
#ifndef _SSH1106_H_
#define _SSH1106_H_

//-----------------------------------------------------------------
#ifdef __cplusplus
extern "C"
{
#endif


//#include "stm32f10x.h"
#include "stm32f1xx_hal.h"


#define LCD_I2C_ADDR       0x78//0x3C      /* OLED I2C address         0x78-[0111 1000] / 7A-[0111 1100]*/
#define LCD_STR_LEN        12       // Lenght of String

//   need to check	
#define LCD_MAX_WRITE      16        // Max bytes to write in one step (138 / 8)
 
#define A_WR                  0         // Master will write to the I2C
#define A_RD                  1         // Master will read from the I2C


#define BLACK 			0
#define WHITE 			1
#define INVERSE 		2

typedef enum
{
    PIXEL_OFF =  0,
    PIXEL_ON  =  1,
    PIXEL_XOR =  2

} LcdPixelMode;

typedef enum
{
    FONT_1X = 1,
    FONT_2X = 2

} LcdFontSize;

//#define SSH1106_I2C_ADDRESS   0x3C  // 011110+SA0+RW - 0x3C or 0x3D
// Address for 128x32 is 0x3C
// Address for 128x64 is 0x3D (default) or 0x3C (if SA0 is grounded)

//-----------------------------------------------------------------------
   #define SSH1106_128_64
// 	 #define SSH1106_128_32
//   #define SSH1106_96_16


#define SSH1106_LCDWIDTH                  128
#define SSH1106_LCDHEIGHT                 64
#define SSH1106_PAGES                     8
#define SSH1106_PAGE_WIDTH                (SSH1106_LCDHEIGHT / 8)

#define HORIZONTAL_ADDRESSING_MODE      0x00
#define VERTICAL_ADDRESSING_MODE        0x01
#define PAGE_ADDRESSING_MODE            0x02

// Command and Datamode
#define SSH1106_COMMAND_MODE               0x80 // continuation bit is set!
#define SSH1106_DATA_MODE                  0x40

// Cache size in bytes ( 128 * 64 ) / 8 
#define LCD_CACHE_SIZE             ( ( SSH1106_LCDWIDTH * SSH1106_LCDHEIGHT ) / 8)

// commands
#define SSH1106_SETCONTRAST                 0x81
#define SSH1106_DISPLAYALLON_RESUME 				0xA4
#define SSH1106_DISPLAYALLON                0xA5
#define SSH1106_NORMALDISPLAY               0xA6
#define SSH1106_INVERTDISPLAY               0xA7

#define SSH1106_DISPLAYOFF 					0xAE
#define SSH1106_DISPLAYON 					0xAF

#define SSH1106_SETDISPLAYOFFSET 		0xD3
#define SSH1106_SETCOMPINS 					0xDA

#define SSH1106_SETVCOMDETECT 			0xDB

#define SSH1106_SETDISPLAYCLOCKDIV 	0xD5
#define SSH1106_SETPRECHARGE 				0xD9

#define SSH1106_SETMULTIPLEX 				0xA8    // takes one byte, from 16 to 63

#define SSH1106_SETLOWCOLUMN 				0x00
#define SSH1106_SETHIGHCOLUMN 				0x10

#define SSH1106_SETSTARTLINE 				0x40

#define SSH1106_MEMORYMODE 					0x20
#define SSH1106_COLUMNADDR 					0x21    // takes two bytes, start address and end address of display data RAM
#define SSH1106_PAGEADDR   					0x22    // takes two bytes, start address and end address of display data RAM

#define SSH1106_COMSCANINC 					0xC0
#define SSH1106_COMSCANDEC 					0xC8

#define SSH1106_SEGREMAP 					0xA0

#define SSH1106_CHARGEPUMP 					0x8D

#define SSH1106_EXTERNALVCC 				0x1
#define SSH1106_SWITCHCAPVCC 				0x2

// Scrolling #defines
#define SSH1106_ACTIVATE_SCROLL 			0x2F
#define SSH1106_DEACTIVATE_SCROLL 			0x2E
#define SSH1106_SET_VERTICAL_SCROLL_AREA    0xA3
#define SSH1106_RIGHT_HORIZONTAL_SCROLL     0x26
#define SSH1106_LEFT_HORIZONTAL_SCROLL 	    0x27
#define SSH1106_VERTICAL_AND_RIGHT_HORIZONTAL_SCROLL 0x29
#define SSH1106_VERTICAL_AND_LEFT_HORIZONTAL_SCROLL 0x2A



//intern subroutines
//--------------------------------------------------------------------------------
int32_t I2C_Initialize (void);
int32_t SSH1106_command(uint8_t command);

// public functions
//--------------------------------------------------------------------------------
void SSH1106_Init(void);
void SSH1106_UpdateDisplay(void);
void SSH1106_ClearDisplay(void);
void SSH1106_InvertDisplay(uint8_t i);
void SSH1106_DrawHLine(int16_t x, int16_t y, int16_t w, uint16_t color);

void LcdGotoXYFont( uint16_t x, uint16_t y );
void LcdChr( LcdFontSize size, uint8_t ch );
void LCD_Print( LcdFontSize size, char dataArray[] );
void LCD_PrintInt(LcdFontSize size, int ulValue);
void Convert(char *p, int32_t data);
void LCD_PrintHex( LcdFontSize size, uint8_t Value);


//------------------------------------------------------------------------------------------------
// Mark the end of the C bindings section for C++ compilers.
    #ifdef __cplusplus
    }
    #endif

#endif /* _SSH1106_H_ */
